summaryrefslogtreecommitdiffstats
path: root/dom/file/uri/BlobURLProtocolHandler.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'dom/file/uri/BlobURLProtocolHandler.cpp')
-rw-r--r--dom/file/uri/BlobURLProtocolHandler.cpp7
1 files changed, 3 insertions, 4 deletions
diff --git a/dom/file/uri/BlobURLProtocolHandler.cpp b/dom/file/uri/BlobURLProtocolHandler.cpp
index 3e2d8e788e..978e88cc8b 100644
--- a/dom/file/uri/BlobURLProtocolHandler.cpp
+++ b/dom/file/uri/BlobURLProtocolHandler.cpp
@@ -948,7 +948,7 @@ nsresult NS_GetBlobForBlobURISpec(const nsACString& aSpec,
}
// Blob requests may specify a range header. We parse, validate, and
// store that info here, and save it on the nsBaseChannel, where it
// can be accessed by BlobURLInputStream::StoreBlobImplStream.
nsresult NS_SetChannelContentRangeForBlobURI(nsIChannel* aChannel, nsIURI* aURI,
nsACString& aRangeHeader) {
@@ -963,9 +963,8 @@ nsresult NS_SetChannelContentRangeForBlobURI(nsIChannel* aChannel, nsIURI* aURI,
if (result.Failed()) {
return NS_ERROR_NO_CONTENT;
}
- nsBaseChannel* bchan = static_cast<nsBaseChannel*>(aChannel);
- MOZ_ASSERT(bchan);
- if (!bchan->SetContentRange(aRangeHeader, size)) {
+ nsCOMPtr<nsIBaseChannel> baseChan = do_QueryInterface(aChannel);
+ if (!baseChan || !baseChan->SetContentRangeFromHeader(aRangeHeader, size)) {
return NS_ERROR_NET_PARTIAL_TRANSFER;
}
return NS_OK;
@@ -948,7 +948,7 @@ nsresult NS_GetBlobForBlobURISpec(const nsACString& aSpec,
}
// Blob requests may specify a range header. We parse, validate, and
-// store that info here, and save it on the nsBaseChannel, where it
+// store that info here, and save it on the nsIBaseChannel, where it
// can be accessed by BlobURLInputStream::StoreBlobImplStream.
nsresult NS_SetChannelContentRangeForBlobURI(nsIChannel* aChannel, nsIURI* aURI,